@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2014 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,9 @@
 #include <stdio.h>
 #include <time.h>
 
-#include "procmsg.h"
+#include "proctypes.h"
 
-typedef struct _HeaderEntry	HeaderEntry;
-typedef struct _Header		Header;
+#define AVATAR_HEADER_UPDATE_HOOKLIST "avatar_header_update"
 
 struct _HeaderEntry
 {
@@ -42,21 +41,18 @@ struct _Header
 	gchar *body;
 };
 
-gint procheader_get_one_field		(gchar		*buf,
-					 size_t		 len,
+gint procheader_get_one_field		(gchar		**buf,
 					 FILE		*fp,
 					 HeaderEntry	 hentry[]);
-gint procheader_get_one_field_asis	(gchar		*buf,
-					 size_t		 len,
-					 FILE		*fp);
-gchar *procheader_get_unfolded_line	(gchar		*buf,
-					 size_t		 len,
+gint procheader_get_one_field_asis	(gchar		**buf,
 					 FILE		*fp);
 
 GPtrArray *procheader_get_header_array_asis	(FILE		*fp);
 void procheader_header_array_destroy		(GPtrArray	*harray);
 void procheader_header_free			(Header		*header);
 
+gboolean procheader_skip_headers(FILE *fp);
+
 void procheader_get_header_fields	(FILE		*fp,
 					 HeaderEntry	 hentry[]);
 MsgInfo *procheader_parse_file		(const gchar	*file,
@@ -90,10 +86,10 @@ gboolean procheader_headername_equal    (char * hdr1, char * hdr2);
 void procheader_header_free             (Header * header);
 
 gint procheader_get_header_from_msginfo	(MsgInfo	*msginfo,
-					 gchar		*buf,
-					 gint 		len,
+					 gchar		**buf,
 					 gchar 		*header);
 
 HeaderEntry *procheader_entries_from_str(const gchar	*str);
 void procheader_entries_free		(HeaderEntry	*entries);
+gboolean procheader_header_is_internal	(const gchar	*hdr_name);
 #endif /* __PROCHEADER_H__ */
